@@ -32,6 +32,7 @@
 #include "plugins.h"
 #include "xchat-plugin.h"
 #include "xg-plugin.h"
+#include "preferences-page-plugin-notification.h"
 
 #define NOTIFICATION_VERSION "0.1"
 
@@ -39,6 +40,8 @@ void xchat_plugin_get_info   (char **plugin_name, char **plugin_desc, char **plu
 int  xchat_plugin_init       (xchat_plugin *plugin_handle, char **plugin_name, char **plugin_desc, char **plugin_version, char *arg);
 int  xchat_plugin_deinit     (void);
 int  xchat_gnome_plugin_init (xchat_gnome_plugin *xg_plugin);
+PreferencesPage* xchat_plugin_get_preferences_page (void);
+
 
 /* Enumerated type of different status levels. */
 typedef enum
@@ -59,6 +62,7 @@ static NotifStatus         status = NOTIF_NONE; /* Current status level. */
 static xchat_gnome_plugin* xgph;                /* xchat gnome plugin handle. */
 static xchat_plugin*       ph;                  /* Plugin handle. */
 static guint		   gconf_notify_id;
+
 static const char *images[N_NOTIF] = {
 	"xchat-gnome",
 	"xchat-gnome-message-data",
@@ -79,6 +83,9 @@ got_focus_cb (GtkWidget * widget, GdkEventFocus * event, gpointer data)
 {
 	focused = TRUE;
 
+	if (status == NOTIF_NONE)
+		return FALSE;
+
 	/* Reset the status. */
 	status = NOTIF_NONE;
 
@@ -110,14 +117,6 @@ new_msg_cb (char *word[], void *statusptr)
 	return 0;
 }
 
-static gboolean
-status_icon_size_changed_cb (GtkStatusIcon *icon, gint size, gpointer user_data)
-{
-	update_tray ();
-
-	return TRUE;
-}
-
 static void
 status_icon_activate_cb (GtkStatusIcon *icon, gpointer data)
 {
@@ -135,6 +134,12 @@ status_icon_activate_cb (GtkStatusIcon *icon, gpointer data)
 }
 
 /*** xchat-gnome plugin functions ***/
+PreferencesPage*
+xchat_plugin_get_preferences_page (void)
+{
+	return PREFERENCES_PAGE (preferences_page_plugin_notification_new ());
+}
+
 void
 xchat_plugin_get_info (char **plugin_name, char **plugin_desc, char **plugin_version, void **reserved)
 {
@@ -174,7 +179,6 @@ int
 xchat_plugin_init (xchat_plugin * plugin_handle, char **plugin_name, char **plugin_desc, char **plugin_version, char *arg)
 {
 	GConfClient *client = gconf_client_get_default ();
-	guint i;
 
 	ph = plugin_handle;
 
@@ -191,7 +195,6 @@ xchat_plugin_init (xchat_plugin * plugin_handle, char **plugin_name, char **plug
 	/* Create the notification icon. */
 	status_icon = gtk_status_icon_new ();
 	g_signal_connect (status_icon, "activate", G_CALLBACK (status_icon_activate_cb), NULL);
-	g_signal_connect (status_icon, "size-changed", G_CALLBACK (status_icon_size_changed_cb), NULL);
 	update_tray ();
 
 	/* Hook up our callbacks. */
@@ -214,7 +217,6 @@ int
 xchat_plugin_deinit (void)
 {
 	GConfClient *client = gconf_client_get_default ();
-	guint i;
 
 	/* Disconnect the signal handlers. */
 	g_signal_handlers_disconnect_by_func (main_window, G_CALLBACK (got_focus_cb), NULL);
