@@ -37,6 +37,20 @@ static char RCSID[] = "$Id: tclplugin.c,v 1.59 2005/08/11 02:37:55 mooooooo Exp
 #include <unistd.h>
 #endif
 
+#if defined(ENABLE_NLS) && !defined(_)
+#  include <libintl.h>
+#  define _(x) gettext(x)
+#  ifdef gettext_noop
+#    define N_(String) gettext_noop (String)
+#  else
+#    define N_(String) (String)
+#  endif
+#endif
+#if !defined(_)
+#  define N_(String) (String)
+#  define _(x) (x)
+#endif
+
 #include "xchat-plugin.h"
 #include "tclplugin.h"
 #include "printevents.h"
@@ -2215,8 +2229,8 @@ int xchat_plugin_deinit(void)
 void xchat_plugin_get_info(char **name, char **desc, char **version, void **reserved)
 {
    strncpy(PVERSION, &RCSID[19], 5);
-   *name = "tclplugin";
-   *desc = "Tcl plugin for XChat";
+   *name = _("tclplugin");
+   *desc = _("Tcl plugin for XChat");
    *version = PVERSION;
    if (reserved)
       *reserved = NULL;
