@@ -27,15 +27,13 @@
 void
 show_about_dialog (void)
 {
-	char *license_trans;
-
 	const gchar *authors[] = {
 		"Andre Dahlqvist <andre.bugs@gmail.com>",
 		"Bastien Nocera <hadess@hadess.net>",
 		"Brian Pepple <bdpepple@gmail.com>",
 		"Christian Persch <chpe@gnome.org>",
 		"Dan Kuester <Daniel.Kuester@colorado.edu>",
-		"Daniel Drake <dsd@gentoo.org>"
+		"Daniel Drake <dsd@gentoo.org>",
 		"David Trowbridge <trowbrds@gmail.com>",
 		"Evan Sheehan <Wallace.Sheehan@gmail.com>",
 		"Guillaume Desmottes <cass@skynet.be>",
@@ -59,21 +57,25 @@ show_about_dialog (void)
 		NULL
 	};
 
-	const char *license[] = {
-		N_("X-Chat GNOME is free software; you can redistribute it and/or modify "
-		   "it under the terms of the GNU General Public License as published by "
-		   "the Free Software Foundation; either version 2 of the License, or "
-		   "(at your option) any later version."),
-		N_("X-Chat GNOME is distributed in the hope that it will be useful, "
-		   "but WITHOUT ANY WARRANTY; without even the implied warranty of "
-		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
-		   "GNU General Public License for more details."),
-		N_("You should have received a copy of the GNU General Public License "
-		   "along with X-Chat GNOME; if not, write to the Free Software Foundation, Inc., "
-		   "59 Temple Place, Suite 330, Boston, MA  02111-1307  USA")
+	const gchar *license[] = {
+		N_("X-Chat GNOME is free software; you can redistribute it "
+		   "and/or modify it under the terms of the GNU General "
+		   "Public License as published by the Free Software "
+		   "Foundation; either version 2 of the License, or (at your "
+		   "option) any later version."),
+		N_("X-Chat GNOME is distributed in the hope that it will be "
+		   "useful, but WITHOUT ANY WARRANTY; without even the "
+		   "implied warranty of MERCHANTABILITY or FITNESS FOR A "
+		   "PARTICULAR PURPOSE.  See the GNU General Public License "
+		   "for more details."),
+		N_("You should have received a copy of the GNU General Public "
+		   "License along with X-Chat GNOME; if not, write to the "
+		   "Free Software Foundation, Inc., 59 Temple Place, Suite "
+		   "330, Boston, MA  02111-1307  USA")
 	};
 
-	license_trans = g_strjoin ("\n\n", _(license[0]), _(license[1]), _(license[2]), NULL);
+	gchar *license_trans = g_strjoin ("\n\n", _(license[0]), _(license[1]),
+	                                  _(license[2]), NULL);
 
 	gtk_show_about_dialog (GTK_WINDOW (gui.main_window),
 	                       "name", "XChat-GNOME",
