@@ -99,11 +99,24 @@ dialog_response (ConnectDialog *dialog, gint response, gpointer data)
 			}
 		}
 
-		if (!found) {
+		gtk_widget_destroy (GTK_WIDGET (dialog));
+
+		if(net->servlist == NULL) {
+			GtkWidget *warning_dialog =
+				gtk_message_dialog_new (NULL,
+				                        GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+				                        GTK_MESSAGE_WARNING,
+				                        GTK_BUTTONS_CLOSE,
+				                        _("This network doesn't have a server defined."));
+			gtk_message_dialog_format_secondary_text (GTK_DIALOG (warning_dialog),
+			                                          _("Please add at least one server to the %s network."),
+			                                          net->name);
+			gtk_dialog_run (GTK_DIALOG (warning_dialog));
+			gtk_widget_destroy (warning_dialog);
+
+		} else if (!found) {
 			servlist_connect (s, net, TRUE);
 		}
-
-		gtk_widget_destroy (GTK_WIDGET (dialog));
 	}
 }
 
