@@ -1,7 +1,7 @@
 /*
  * conversation-panel.c - Widget encapsulating the conversation panel
  *
- * Copyright (C) 2004-2006 xchat-gnome team
+ * Copyright (C) 2004-2007 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,9 +25,7 @@
 #include <gconf/gconf-client.h>
 #include <libgnomeui/gnome-stock-icons.h>
 #include <libgnomevfs/gnome-vfs.h>
-#ifdef HAVE_LIBSEXY
 #include <libsexy/sexy-tooltip.h>
-#endif
 
 #include "conversation-panel.h"
 #include "gui.h"
@@ -57,7 +55,6 @@ static void     conversation_panel_clicked_word       (GtkWidget              *x
                                                        char                   *word,
                                                        GdkEventButton         *event,
                                                        ConversationPanel      *panel);
-#ifdef HAVE_LIBSEXY
 static void     conversation_panel_enter_word         (GtkWidget              *xtext,
                                                        char                   *word,
                                                        ConversationPanel      *panel);
@@ -67,7 +64,6 @@ static void     conversation_panel_leave_word         (GtkWidget              *x
 static gboolean conversation_panel_lost_focus         (GtkWidget              *widget,
                                                        GdkEventFocus          *event,
                                                        ConversationPanel      *panel);
-#endif
 static void     conversation_panel_set_font           (ConversationPanel      *panel);
 static void     conversation_panel_font_changed       (GConfClient            *client,
                                                        guint                   cnxn_id,
@@ -129,9 +125,7 @@ static void     on_default_copy_activate              (GtkAction              *a
                                                        ConversationPanel      *panel);
 static gboolean uri_is_text                           (gchar                  *uri);
 static gboolean check_file_size                       (gchar                  *uri);
-#ifdef HAVE_LIBSEXY
 GtkWidget* get_user_vbox_infos                        (struct User            *user);
-#endif
 static void redraw_transparency                       (ConversationPanel      *panel);
 #ifdef USE_XLIB
 static GdkFilterReturn root_event_cb                  (GdkXEvent              *xev,
@@ -159,10 +153,8 @@ struct _ConversationPanelPriv
 	gchar          *selected_word;
 	GSList         *dropped_files;
 
-#ifdef HAVE_LIBSEXY
 	GtkWidget      *current_tooltip;
 	guint           tooltip_timeout;
-#endif
 	gboolean        redundant_nickstamps;
 };
 
@@ -263,10 +255,9 @@ conversation_panel_init (ConversationPanel *panel)
 	gtk_ui_manager_insert_action_group (gui.manager, action_group, 0);
 	g_object_unref (action_group);
 
-#ifdef HAVE_LIBSEXY
 	panel->priv->tooltip_timeout = 0;
 	panel->priv->current_tooltip = NULL;
-#endif
+
 	client = gconf_client_get_default ();
 	panel->priv->redundant_nickstamps =
 		gconf_client_get_bool (client, "/apps/xchat/main_window/redundant_nickstamps", NULL);
@@ -325,12 +316,10 @@ conversation_panel_realize (GtkWidget *widget)
 	conversation_panel_set_background (panel);
 
 	g_signal_connect (G_OBJECT (panel->priv->xtext), "word_click",      G_CALLBACK (conversation_panel_clicked_word), panel);
-#ifdef HAVE_LIBSEXY
 	g_signal_connect (G_OBJECT (panel->priv->xtext), "word_enter",      G_CALLBACK (conversation_panel_enter_word),   panel);
 	g_signal_connect (G_OBJECT (panel->priv->xtext), "word_leave",      G_CALLBACK (conversation_panel_leave_word),   panel);
 	g_signal_connect (G_OBJECT (gui.main_window),    "focus-out-event", G_CALLBACK (conversation_panel_lost_focus),   panel);
 	g_signal_connect (G_OBJECT (gui.main_window),    "leave-notify-event", G_CALLBACK (conversation_panel_lost_focus),   panel);
-#endif
 	gconf_client_notify_add (client, "/apps/xchat/main_window/use_sys_fonts",
 	                         (GConfClientNotifyFunc) conversation_panel_font_changed,       panel, NULL, NULL);
 	gconf_client_notify_add (client, "/apps/xchat/main_window/font",
@@ -503,7 +492,6 @@ conversation_panel_clicked_word (GtkWidget *xtext, char *word, GdkEventButton *e
 	}
 }
 
-#ifdef HAVE_LIBSEXY
 static gboolean
 show_user_tooltip (gchar *nick)
 {
@@ -583,7 +571,6 @@ conversation_panel_lost_focus (GtkWidget *widget, GdkEventFocus *event, Conversa
 	conversation_panel_remove_tooltip (panel);
 	return FALSE;
 }
-#endif
 
 static void
 conversation_panel_set_font (ConversationPanel *panel)
@@ -698,8 +685,15 @@ open_url (GtkAction *action, ConversationPanel *panel)
 static void
 copy_text (GtkAction *action, ConversationPanel *panel)
 {
-	GtkClipboard *clipboard = gtk_widget_get_clipboard (GTK_WIDGET (panel), GDK_SELECTION_CLIPBOARD);
-        gtk_clipboard_set_text (clipboard, panel->priv->selected_word, -1);
+	GdkDisplay *display;
+	GtkClipboard *clipboard;
+
+	display = gtk_widget_get_display (GTK_WIDGET (panel));
+
+	clipboard = gtk_clipboard_get_for_display (display, GDK_SELECTION_PRIMARY);
+	gtk_clipboard_set_text (clipboard, panel->priv->selected_word, -1);
+	clipboard = gtk_clipboard_get_for_display (display, GDK_SELECTION_CLIPBOARD);
+	gtk_clipboard_set_text (clipboard, panel->priv->selected_word, -1);
 }
 
 static void
@@ -796,7 +790,7 @@ drag_data_received (GtkWidget *widget, GdkDragContext *context, gint x, gint y,
 		}
 
 		if (selection_data->format != 8 || selection_data->length == 0) {
-			g_printerr (_("URI list dropped on xchat-gnome had wrong format (%d) or length (%d)\n"),
+			g_printerr (_("URI list dropped on XChat-GNOME had wrong format (%d) or length (%d)\n"),
 			            selection_data->format, selection_data->length);
 			return;
 		}
@@ -1024,9 +1018,7 @@ conversation_panel_set_current (ConversationPanel *panel, struct session *sess)
 		xtext_buffer_show (XTEXT (panel->priv->xtext), XTEXT (panel->priv->xtext)->orig_buffer, TRUE);
 	}
 
-#ifdef HAVE_LIBSEXY
 	conversation_panel_remove_tooltip (panel);
-#endif
 }
 
 void
@@ -1105,7 +1097,7 @@ conversation_panel_print_line (ConversationPanel *panel, xtext_buffer *buffer, g
 	unsigned char *tab;
 
 	if (len == 0) {
-		len = 1;
+		return;
 	}
 
 	if (indent == FALSE) {
@@ -1148,6 +1140,10 @@ conversation_panel_print (ConversationPanel *panel, struct session *sess, guchar
 	guchar       *last_text = text;
 	int           len       = 0;
 
+	if (strlen (text) == 0) {
+		return;
+	}
+
 	buffer = g_hash_table_lookup (panel->priv->buffers, sess);
 	if (buffer == NULL) {
 		return;
