@@ -137,17 +137,17 @@ fe_init (void)
 
 	u = userlist_new ();
 	gui.quit = FALSE;
-	servlist_init ();
 	palette_init ();
 	run_migrations ();
+	initialize_gui_1 ();
 	if (!preferences_exist ()) {
 		run_setup_dialog ();
 	} else {
 		set_version ();
 	}
-	load_preferences ();
-	initialize_gui_1 ();
+	servlist_init ();
 	initialize_gui_2 ();
+	load_preferences ();
 	run_main_window ();
 
 	/* Force various window-related options to match our interaction model */
@@ -236,19 +236,6 @@ fe_new_window (struct session *sess, int focus)
 		navigation_model_add_channel (gui.tree_model, sess);
 	}
 
-	/*
-	} else if (sess->type == SESS_DIALOG) {
-		struct User *user = NULL;
-
-		user = userlist_find_global (sess->server, sess->channel);
-
-		navigation_tree_create_new_channel_entry (gui.server_tree, sess, (gboolean) focus);
-		if (user) {
-			topic_label_set_topic (TOPIC_LABEL (gui.topic_label), sess, user->hostname);
-		}
-	}
-	*/
-
 	if (focus) {
 		navigation_tree_select_session (gui.server_tree, sess);
 	}
@@ -425,6 +412,10 @@ fe_close_window (struct session *sess)
 		status_bar_remove_server (STATUS_BAR (gui.status_bar), sess->server);
 	}
 
+	if (sess == gui.current_session) {
+		gui.current_session = NULL;
+	}
+
 	session_free (sess);
 }
 
@@ -441,9 +432,15 @@ fe_progressbar_end (struct server *serv)
 }
 
 void
-fe_print_text (struct session *sess, char *text)
+fe_print_text (struct session *sess, char *text, time_t stamp)
 {
-	conversation_panel_print (CONVERSATION_PANEL (gui.conversation_panel), sess, text, prefs.indent_nicks);
+	if (text == NULL) {
+		g_warning ("NULL passed to fe_print_text.  Perhaps a misbehaving plugin?\n");
+		return;
+	}
+
+	conversation_panel_print (CONVERSATION_PANEL (gui.conversation_panel),
+	                          sess, (guchar*) text, prefs.indent_nicks);
 	sess->new_data = TRUE;
 	navigation_model_set_hilight (gui.tree_model, sess);
 	if (sess->nick_said) {
@@ -650,7 +647,7 @@ fe_set_nonchannel (struct session *sess, int state)
 void
 fe_set_nick (struct server *serv, char *newnick)
 {
-	set_nickname (serv, newnick);
+	set_nickname_label (serv, newnick);
 }
 
 void
@@ -718,30 +715,30 @@ fe_serverlist_open (session * sess)
 }
 
 void
-fe_ctrl_gui (session * sess, int action, int arg)
+fe_ctrl_gui (session * sess, fe_gui_action action, int arg)
 {
 	switch (action) {
-	case 0:
+	case FE_GUI_HIDE:
 		gtk_widget_hide (gui.main_window);
 		break;
 
-	case 1:
+	case FE_GUI_SHOW:
 		gtk_widget_show (gui.main_window);
 		gtk_window_present (GTK_WINDOW (gui.main_window));
 		break;
 
-	case 2:
-		break;
-
-	case 3:
-		break;
-
-	case 4:
-		break;
-
-	case 5:
+	case FE_GUI_ICONIFY:
 		gtk_window_iconify (GTK_WINDOW (gui.main_window));
 		break;
+
+	case FE_GUI_FOCUS:
+	case FE_GUI_FLASH:
+	case FE_GUI_MENU:
+	case FE_GUI_ATTACH:
+	case FE_GUI_APPLY:
+	case FE_GUI_COLOR:
+		/* These are unhandled for now */
+		break;
 	}
 }
 
@@ -1122,7 +1119,7 @@ fe_set_current (session *sess)
 	}
 
 	// Set nickname button
-	set_nickname (sess->server, NULL);
+	set_nickname_label (sess->server, NULL);
 
 	// Set the label of the user list button
 	userlist_set_user_button (u, sess);
@@ -1136,3 +1133,10 @@ fe_set_current (session *sess)
 
 	gtk_widget_grab_focus (GTK_WIDGET (gui.text_entry));
 }
+
+/* Tray stubs -- xchat-gnome bundles this as a plugin */
+void fe_tray_set_flash (const char *filename1, const char *filename2, int timeout) {}
+void fe_tray_set_file (const char *filename) {}
+void fe_tray_set_icon (feicon icon) {}
+void fe_tray_set_tooltip (const char *text) {}
+void fe_tray_set_balloon (const char *title, const char *text) {}
