@@ -44,12 +44,13 @@ initialize_gui_1 (void)
 	gui.manager = gtk_ui_manager_new ();
 
 	gchar *path = locate_data_file ("xchat-gnome.glade");
+	g_assert (path != NULL);
+
 	gui.xml = glade_xml_new (path, NULL, NULL);
+	g_assert(gui.xml != NULL);
+
 	g_free (path);
 
-	if (!gui.xml) {
-		return FALSE;
-	}
 	return TRUE;
 }
 
@@ -67,9 +68,10 @@ initialize_gui_2 (void)
 	initialize_userlist ();
 	initialize_main_window ();
 
-	widget = glade_xml_get_widget (gui.xml, "server channel list");
-	gtk_widget_show (GTK_WIDGET (gui.server_tree));
-	gtk_container_add (GTK_CONTAINER (widget), GTK_WIDGET (gui.server_tree));
+	gtk_container_add (
+		GTK_CONTAINER (glade_xml_get_widget (gui.xml,
+		                                     "server channel list")),
+		GTK_WIDGET (gui.server_tree));
 
 	gui.dcc = dcc_window_new ();
 
