@@ -256,20 +256,18 @@ irc_network_editor_init (IrcNetworkEditor *dialog)
 {
 	gchar **enc;
 	GtkTreeSelection *server_selection, *autojoin_selection;
-	GladeXML *xml;
-	gchar *path;
 
 	dialog->gconf = NULL;
 	dialog->network = NULL;
 	dialog->toplevel = NULL;
 
-	xml = NULL;
-	path = locate_data_file ("irc-network-editor.glade");
-	xml = glade_xml_new (path, "toplevel", NULL);
+	gchar *path = locate_data_file ("irc-network-editor.glade");
+	g_assert (path != NULL);
+
+	GladeXML *xml = glade_xml_new (path, "toplevel", NULL);
+	g_assert (xml != NULL);
+
 	g_free (path);
-	if (!xml) {
-		return;
-	}
 
 #define GW(name) ((dialog->name) = glade_xml_get_widget (xml, #name))
 	GW(network_settings_table);
