@@ -136,7 +136,6 @@ initialize_main_window (void)
 	GtkWidget *close, *menu_vbox, *widget;
 	GtkSizeGroup *group;
 	GtkAction *action;
-	gchar *path;
 
 	gui.main_window = glade_xml_get_widget (gui.xml, "xchat-gnome");
 	g_signal_connect (G_OBJECT (gui.main_window), "delete-event",    G_CALLBACK (on_main_window_close),     NULL);
@@ -155,7 +154,8 @@ initialize_main_window (void)
 	g_signal_connect (gui.manager, "add-widget", G_CALLBACK (on_add_widget), menu_vbox);
 
 	/* load the menus */
-	path = locate_data_file ("xchat-gnome-ui.xml");
+	gchar *path = locate_data_file ("xchat-gnome-ui.xml");
+	g_assert (path != NULL);
 	gtk_ui_manager_add_ui_from_file (gui.manager, path, NULL);
 	g_free (path);
 
@@ -589,7 +589,7 @@ on_users_toggled (GtkToggleButton *widget, gpointer user_data)
 }
 
 void
-set_nickname (struct server *serv, char *newnick)
+set_nickname_label (struct server *serv, char *newnick)
 {
 	GtkLabel *label;
 
