@@ -30,8 +30,6 @@
 /***** NavTree *****/
 static void navigation_tree_init       (NavTree *navtree);
 static void navigation_tree_class_init (NavTreeClass *klass);
-static void navigation_tree_dispose    (GObject *object);
-static void navigation_tree_finalize   (GObject *object);
 static gint tree_iter_sort_func_nocase (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer data);
 
 static void     row_inserted      (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, NavTree *tree);
@@ -78,8 +76,6 @@ enum
 
 static void     navigation_model_init       (NavModel * navmodel);
 static void     navigation_model_class_init (NavModelClass * klass);
-static void     navigation_model_dispose    (GObject * object);
-static void     navigation_model_finalize   (GObject * object);
 
 /********** Utility **********/
 
@@ -179,19 +175,6 @@ navigation_tree_class_init (NavTreeClass *klass)
 	GObjectClass *object_class = (GObjectClass *) klass;
 
 	g_type_class_add_private (object_class, sizeof (NavTreePriv));
-
-	object_class->dispose = navigation_tree_dispose;
-	object_class->finalize = navigation_tree_finalize;
-}
-
-static void
-navigation_tree_dispose (GObject *object)
-{
-}
-
-static void
-navigation_tree_finalize (GObject *object)
-{
 }
 
 NavTree *
@@ -472,19 +455,6 @@ navigation_model_init (NavModel *navmodel)
 
 static void
 navigation_model_class_init (NavModelClass *klass)
-{
-	GObjectClass *object_class = (GObjectClass *) klass;
-	object_class->dispose = navigation_model_dispose;
-	object_class->finalize = navigation_model_finalize;
-}
-
-static void
-navigation_model_dispose (GObject *object)
-{
-}
-
-static void
-navigation_model_finalize (GObject *object)
 {
 }
 
