@@ -39,7 +39,6 @@ static gboolean   text_entry_key_press         (GtkWidget      *widget,
                                                 gpointer        data);
 static void       text_entry_grab_focus        (GtkWidget      *widget);
 
-#ifdef HAVE_LIBSEXY
 static gboolean   text_entry_spell_check       (TextEntry      *entry,
                                                 gchar          *text,
                                                 gpointer        data);
@@ -47,7 +46,6 @@ static void       enable_spellcheck_changed    (GConfClient    *client,
 		                                guint           cnxn_id,
 					        GConfEntry     *gconf_entry,
 					        TextEntry      *entry);
-#endif
 static void       text_entry_activate          (GtkWidget      *widget,
                                                 gpointer        data);
 static void       text_entry_history_up        (GtkEntry       *entry);
@@ -65,13 +63,8 @@ static GtkWidget *get_color_icon               (int             c,
 static void       color_code_activate          (GtkMenuItem    *item,
                                                 gpointer        data);
 
-#ifdef HAVE_LIBSEXY
 static SexySpellEntryClass *parent_class = NULL;
 G_DEFINE_TYPE (TextEntry, text_entry, SEXY_TYPE_SPELL_ENTRY);
-#else
-static GtkEntryClass       *parent_class = NULL;
-G_DEFINE_TYPE (TextEntry, text_entry, GTK_TYPE_ENTRY);
-#endif
 
 gpointer *entry_parent_class;
 
@@ -103,19 +96,15 @@ text_entry_init (TextEntry *entry)
 {
 	GList *items = NULL;
 	int i;
-#ifdef HAVE_LIBSEXY
 	GConfClient *client;
 	gboolean enable_spellcheck;
 	GSList *languages;
 	GError *err  = NULL;
-#endif
 
 	g_signal_connect_after (G_OBJECT (entry), "key_press_event",         G_CALLBACK (text_entry_key_press),         NULL);
 	g_signal_connect       (G_OBJECT (entry), "activate",                G_CALLBACK (text_entry_activate),          NULL);
 	g_signal_connect       (G_OBJECT (entry), "populate-popup",          G_CALLBACK (text_entry_populate_popup),    NULL);
-#ifdef HAVE_LIBSEXY
 	g_signal_connect_after (G_OBJECT (entry), "word-check",              G_CALLBACK (text_entry_spell_check),       NULL);
-#endif
 
 	entry->priv = g_new0 (TextEntryPriv, 1);
 
@@ -131,7 +120,6 @@ text_entry_init (TextEntry *entry)
 	g_completion_add_items (entry->priv->command_completion, items);
 	g_list_free (items);
 
-#ifdef HAVE_LIBSEXY
 	/* Setup spellchecking */
 	client = gconf_client_get_default ();
 
@@ -166,7 +154,6 @@ text_entry_init (TextEntry *entry)
 	                         (GConfClientNotifyFunc) enable_spellcheck_changed, entry, NULL, NULL);
 
 	g_object_unref (client);
-#endif
 
 	gtk_widget_show (GTK_WIDGET (entry));
 }
@@ -231,7 +218,6 @@ text_entry_grab_focus (GtkWidget *widget)
 	GTK_WIDGET_CLASS (entry_parent_class)->grab_focus (widget);
 }
 
-#ifdef HAVE_LIBSEXY
 static gboolean
 text_entry_spell_check (TextEntry *entry, gchar *text, gpointer data)
 {
@@ -257,7 +243,6 @@ text_entry_spell_check (TextEntry *entry, gchar *text, gpointer data)
 	} while (gtk_tree_model_iter_next (store, &iter));
 	return TRUE;
 }
-#endif
 
 static void
 text_entry_activate (GtkWidget *widget, gpointer data)
@@ -711,7 +696,6 @@ text_entry_remove_session (TextEntry *entry, struct session *sess)
 	}
 }
 
-#ifdef HAVE_LIBSEXY
 static void
 enable_spellcheck_changed (GConfClient *client, guint cnxn_id, GConfEntry *gconf_entry, TextEntry *entry)
 {
@@ -735,4 +719,3 @@ enable_spellcheck_changed (GConfClient *client, guint cnxn_id, GConfEntry *gconf
 		g_slist_free (langs);
 	}
 }
-#endif
