@@ -23,9 +23,7 @@
 #include <glib/gi18n.h>
 #include <gnome.h>
 #include <string.h>
-#ifdef HAVE_LIBSEXY
 #include <libsexy/sexy-tree-view.h>
-#endif
 #include "userlist-gui.h"
 #include "pixmaps.h"
 #include "palette.h"
@@ -44,10 +42,8 @@ static gboolean userlist_window_grab_broken (GtkWidget *window, GdkEventGrabBrok
 static void     userlist_popup_deactivate   (GtkMenuShell *menu, gpointer data);
 static gboolean userlist_button_release     (GtkWidget *widget, GdkEventButton *button, gpointer data);
 struct User*    userlist_get_selected       (void);
-#ifdef HAVE_LIBSEXY
 GtkWidget* get_user_vbox_infos	    	    (struct User *user);
 static GtkWidget* get_user_tooltip	    (SexyTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer data);
-#endif
 
 /* action callbacks */
 static void user_send_file_activate   (GtkAction *action, gpointer data);
@@ -78,11 +74,7 @@ initialize_userlist (void)
 	GtkTreeSelection *select;
 	GtkWidget *swin;
 
-#ifdef HAVE_LIBSEXY
 	gui.userlist = sexy_tree_view_new ();
-#else
-	gui.userlist = gtk_tree_view_new ();
-#endif
 	gtk_widget_show (gui.userlist);
 	gui.userlist_window = glade_xml_get_widget (gui.xml, "userlist_window");
 
@@ -106,9 +98,7 @@ initialize_userlist (void)
 	g_signal_connect (G_OBJECT (gui.userlist_window), "button_release_event", G_CALLBACK (userlist_button_release), NULL);
 	g_signal_connect (G_OBJECT (gui.userlist_window), "grab_broken_event", G_CALLBACK (userlist_window_grab_broken), NULL);
 	g_signal_connect (G_OBJECT (gui.userlist_window), "event", G_CALLBACK (userlist_window_event), NULL);
-#ifdef HAVE_LIBSEXY
 	g_signal_connect(G_OBJECT (gui.userlist), "get-tooltip", G_CALLBACK (get_user_tooltip), NULL);
-#endif
 
 	GtkActionGroup *group = gtk_action_group_new ("UserlistPopup");
 	gtk_action_group_set_translation_domain (group, GETTEXT_PACKAGE);
@@ -409,7 +399,6 @@ userlist_button_release (GtkWidget *widget, GdkEventButton *button, gpointer dat
 	return TRUE;
 }
 
-#ifdef HAVE_LIBSEXY
 GtkWidget*
 get_user_vbox_infos (struct User *user)
 {
@@ -468,16 +457,15 @@ get_user_vbox_infos (struct User *user)
 static GtkWidget*
 get_user_tooltip (SexyTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer data)
 {
-	struct User *user;
-
 	if (FALSE == GTK_WIDGET_VISIBLE (gui.userlist_window)) {
 		return NULL;
 	}
 
-	user = userlist_get_selected ();
+	struct User *user = userlist_get_selected ();
 
 	if (user) {
 		return get_user_vbox_infos (user);
 	}
+
+	return NULL;
 }
-#endif
